###################################################
### chunk number 1: preliminaries
###################################################
#line 87 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
options(width = 70, prompt = "R> ", continue = "+  ", useFancyQuotes = FALSE)
library("betareg")
combine <- function(x, sep, width) {
  cs <- cumsum(nchar(x))
  remaining <- if (any(cs[-1] > width)) combine(x[c(FALSE, cs[-1] > width)], sep, width)
  c(paste(x[c(TRUE, cs[-1] <= width)], collapse= sep), remaining)
}
prettyPrint <- function(x, sep = " ", linebreak = "\n\t", width = getOption("width")) {
  x <- strsplit(x, sep)[[1]]
  paste(combine(x, sep, width), collapse = paste(sep, linebreak, collapse = ""))
}
cache <- FALSE
enumerate <- function(x) paste(paste(x[-length(x)], collapse = ", "), x[length(x)], sep = " and ")
betamix_methods <-
  enumerate(paste("\\\\fct{", gsub("\\.betamix", "", as.character(methods(class = "betamix"))), "}", sep = ""))


###################################################
### chunk number 2: 
###################################################
#line 773 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
cat(prettyPrint(prompt(extraComponent, filename = NA)$usage[[2]], sep = ", ",
  linebreak = paste("\n", paste(rep(" ", 2), collapse = ""), sep= ""),
  width = 60))


###################################################
### chunk number 3: 
###################################################
#line 783 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
data("ReadingSkills", package = "betareg")
mean_accuracy <-
  format(round(with(ReadingSkills, tapply(accuracy, dyslexia, mean)), digits = 3),
         nsmall = 3)
mean_iq <-
  format(round(with(ReadingSkills, tapply(iq, dyslexia, mean)), digits = 3),
         nsmall = 3)


###################################################
### chunk number 4: ReadingSkills
###################################################
#line 828 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
data("ReadingSkills", package = "betareg")
rs_ols <- lm(qlogis(accuracy) ~ dyslexia * iq, data = ReadingSkills)
rs_beta <- betareg(accuracy ~ dyslexia * iq | dyslexia + iq,
  data = ReadingSkills, hessian = TRUE)
cl1 <- hcl(c(260, 0), 90, 40)
cl2 <- hcl(c(260, 0), 10, 95)
plot(accuracy ~ iq, data = ReadingSkills, col = cl2[as.numeric(dyslexia)],
  main = "Reading skills data", xlab = "IQ score", ylab = "Reading accuracy",
  pch = c(19, 17)[as.numeric(dyslexia)], cex = 1.5)
points(accuracy ~ iq, data = ReadingSkills, cex = 1.5,
  pch = (1:2)[as.numeric(dyslexia)], col = cl1[as.numeric(dyslexia)])
nd <- data.frame(dyslexia = "no", iq = -30:30/10)
lines(nd$iq, predict(rs_beta, nd), col = cl1[1], lwd = 2)
lines(nd$iq, plogis(predict(rs_ols, nd)), col = cl1[1], lty = 2, lwd = 2)
nd <- data.frame(dyslexia = "yes", iq = -30:30/10)
lines(nd$iq, predict(rs_beta, nd), col = cl1[2], lwd = 2)
lines(nd$iq, plogis(predict(rs_ols, nd)), col = cl1[2], lty = 2, lwd = 2)
legend("topleft", c("control", "dyslexic", "betareg", "lm"),
  lty = c(NA, NA, 1:2), pch = c(19, 17, NA, NA), lwd = 2,
  col = c(cl2, 1, 1), bty = "n")
legend("topleft", c("control", "dyslexic", "betareg", "lm"),
  lty = c(NA, NA, 1:2), pch = c(1, 2, NA, NA),
  col = c(cl1, NA, NA), bty = "n")


###################################################
### chunk number 5: ReadingSkills-bias
###################################################
#line 879 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
data("ReadingSkills", package = "betareg")
rs_f <- accuracy ~ dyslexia * iq | dyslexia * iq
rs_ml <- betareg(rs_f, data = ReadingSkills, type = "ML")
rs_bc <- betareg(rs_f, data = ReadingSkills, type = "BC")
rs_br <- betareg(rs_f, data = ReadingSkills, type = "BR")


###################################################
### chunk number 6: ReadingSkills-bias-table
###################################################
#line 893 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
rs_list <- list(rs_ml, rs_bc, rs_br)
cf <- paste("$", format(round(sapply(rs_list, coef), digits = 3), nsmall = 3), "$\\phantom{)}", sep = "")
se <- paste("(", format(round(sapply(rs_list, function(x) sqrt(diag(vcov(x)))), digits = 3), nsmall = 3), ")", sep = "")
ll <- paste("$", format(round(sapply(rs_list, logLik), digits = 3), nsmall = 3), "$\\phantom{)}", sep = "")
cfse <- matrix(as.vector(rbind(cf, se)), ncol = 3)
cfse <- cbind(
  c("Mean", rep("", 7), "Precision", rep("", 7)),
  rep(as.vector(rbind(c("(Intercept)", "\\code{dyslexia}", "\\code{iq}", "\\code{dyslexia:iq}"), "")), 2),
  cfse[, 1:2],
  paste(cfse[,3],
    c(rep("\\\\", 7), "\\\\ \\hline", rep("\\\\", 7), "\\\\ \\hline")))
cfse <- rbind(cfse, c("Log-likelihood", "", ll[1:2], paste(ll[3], "\\\\ \\hline")))
writeLines(apply(cfse, 1, paste, collapse = " & "))


###################################################
### chunk number 7: ReadingSkills-phi-plot
###################################################
#line 923 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
pr_phi <- sapply(list("Maximum likelihood" = rs_ml,
                      "Bias correction" = rs_bc,
                      "Bias reduction" = rs_br), predict, type = "precision")
pairs(log(pr_phi), panel = function(x, y, ...) {
  panel.smooth(x, y, ...)
  abline(0, 1, lty = 2)
  })


###################################################
### chunk number 8: ReadingSkills-noise
###################################################
#line 991 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
set.seed(1071)
n <- nrow(ReadingSkills)
ReadingSkills$x1 <- rnorm(n)
ReadingSkills$x2 <- runif(n)
ReadingSkills$x3 <- factor(sample(0:1, n, replace = TRUE))


###################################################
### chunk number 9: ReadingSkills-tree eval=FALSE
###################################################
## #line 1009 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
## rs_tree <- betatree(accuracy ~ iq | iq, ~ dyslexia + x1 + x2 + x3,
##   data = ReadingSkills, minsplit = 10)


###################################################
### chunk number 10: ReadingSkills-tree0
###################################################
#line 1014 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
if(cache & file.exists("betareg-ext-betatree.rda")) {
  load("betareg-ext-betatree.rda")
} else {
#line 1009 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw#from line#1017#"
rs_tree <- betatree(accuracy ~ iq | iq, ~ dyslexia + x1 + x2 + x3,
  data = ReadingSkills, minsplit = 10)
#line 1018 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
if(cache) {
  save(rs_tree, file = "betareg-ext-betatree.rda")
} else {
  if(file.exists("betareg-ext-betatree.rda")) file.remove("betareg-ext-betatree.rda")
}
}


###################################################
### chunk number 11: ReadingSkills-tree2 eval=FALSE
###################################################
## #line 1031 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
## rs_tree <- betatree(accuracy ~ iq | iq | dyslexia + x1 + x2 + x3,
##   data = ReadingSkills, minsplit = 10)


###################################################
### chunk number 12: ReadingSkills-tree3
###################################################
#line 1042 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
plot(rs_tree)


###################################################
### chunk number 13: ReadingSkills-tree-plot
###################################################
#line 1049 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
plot(rs_tree)


###################################################
### chunk number 14: ReadingSkills-tree-coef
###################################################
#line 1071 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
coef(rs_tree)


###################################################
### chunk number 15: ReadingSkills-tree-sctest
###################################################
#line 1094 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
sctest(rs_tree)


###################################################
### chunk number 16: ReadingSkills-mix eval=FALSE
###################################################
## #line 1136 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
## rs_mix <- betamix(accuracy ~ iq, data = ReadingSkills, k = 3,
##   extra_components = extraComponent(type = "uniform",
##     coef = 0.99, delta = 0.01), nstart = 10)


###################################################
### chunk number 17: ReadingSkills-mix2
###################################################
#line 1142 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
if(cache & file.exists("betareg-ext-betamix.rda")) {
 load("betareg-ext-betamix.rda")
} else {
#line 1136 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw#from line#1145#"
rs_mix <- betamix(accuracy ~ iq, data = ReadingSkills, k = 3,
  extra_components = extraComponent(type = "uniform",
    coef = 0.99, delta = 0.01), nstart = 10)
#line 1146 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
if(cache) {
  save(rs_mix, file = "betareg-ext-betamix.rda")
} else {
  if(file.exists("betareg-ext-betamix.rda")) file.remove("betareg-ext-betamix.rda")
}
}


###################################################
### chunk number 18: ReadingSkills-mix3
###################################################
#line 1177 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
rs_mix


###################################################
### chunk number 19: ReadingSkills-mix4
###################################################
#line 1186 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
summary(rs_mix)


###################################################
### chunk number 20: ReadingSkills-betamix-plot1 eval=FALSE
###################################################
## #line 1198 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
## ix <- as.numeric(ReadingSkills$dyslexia)
## col1 <- hcl(c(260, 0), 90, 40)[ix]
## col2 <- hcl(c(260, 0), 10, 95)[ix]
## plot(accuracy ~ iq, data = ReadingSkills, col = col2, pch = 19,
##   cex = 1.5, xlim = c(-2, 2), main = "Partitioned model (dyslexia observed)")
## points(accuracy ~ iq, data = ReadingSkills, cex = 1.5, pch = 1, col = col1)


###################################################
### chunk number 21: ReadingSkills-betamix-plot3
###################################################
#line 1210 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
par(mfrow = c(1, 2))
ix <- as.numeric(ReadingSkills$dyslexia)
prob <- 2 * (posterior(rs_mix)[cbind(seq_along(ix), clusters(rs_mix))] - 0.5)
col3 <- hcl(c(0, 260, 130), 65, 45, fixup = FALSE)
col1 <- col3[clusters(rs_mix)]
col2 <- hcl(c(0, 260, 130)[clusters(rs_mix)], 65 * abs(prob)^1.5, 95 - 50 * abs(prob)^1.5, fixup = FALSE)
plot(accuracy ~ iq, data = ReadingSkills, col = col2, pch = 19, cex = 1.5,
  xlim = c(-2, 2), main = "Mixture model (dyslexia unobserved)")
points(accuracy ~ iq, data = ReadingSkills, cex = 1.5, pch = 1, col = col1)
iq <- -30:30/10
cf <- rbind(coef(rs_mix, model = "mean", component = 1:2), c(qlogis(0.99), 0))
for(i in 1:3) lines(iq, plogis(cf[i, 1] + cf[i, 2] * iq), lwd = 2, col = col3[i])
#line 1198 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw#from line#1222#"
ix <- as.numeric(ReadingSkills$dyslexia)
col1 <- hcl(c(260, 0), 90, 40)[ix]
col2 <- hcl(c(260, 0), 10, 95)[ix]
plot(accuracy ~ iq, data = ReadingSkills, col = col2, pch = 19,
  cex = 1.5, xlim = c(-2, 2), main = "Partitioned model (dyslexia observed)")
points(accuracy ~ iq, data = ReadingSkills, cex = 1.5, pch = 1, col = col1)
#line 1223 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
cf <- coef(rs_tree, model = "mean")
col3 <- hcl(c(260, 0), 90, 40)
for(i in 1:2) lines(iq, plogis(cf[i, 1] + cf[i, 2] * iq), lwd = 2, col = col3[i])


###################################################
### chunk number 22: ReadingSkills-mix5
###################################################
#line 1243 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
table(clusters(rs_mix), ReadingSkills$dyslexia)


###################################################
### chunk number 23: GasolineYield-bias
###################################################
#line 1343 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
data("GasolineYield", package = "betareg")
gy <- lapply(c("ML", "BC", "BR"), function(x)
  betareg(yield ~ batch + temp, data = GasolineYield, type = x))


###################################################
### chunk number 24: ReadingSkills-bias-table
###################################################
#line 1354 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
cf <- matrix(paste("$", format(round(sapply(gy, coef), digits = 5), nsmall = 5), "$\\phantom{)}", sep = ""), ncol = 3)
se <- matrix(gsub(" ", "",
  paste("(", format(round(sapply(gy, function(x) sqrt(diag(vcov(x)))), digits = 5), nsmall = 5), ")", sep = ""),
  fixed = TRUE), ncol = 3)
cfse <- cbind(cf[,1], se[,1], cf[,2], se[,2], cf[,3], se[,3])
cfse <- cbind(
  c(paste("$\\beta_{", 1:11, "}$", sep = ""), "$\\phi$"),
  cfse[, 1:5],
  paste(cfse[,6],
    c(rep("\\\\", 11), "\\\\ \\hline")))
writeLines(apply(cfse, 1, paste, collapse = " & "))


###################################################
### chunk number 25: GasolineYield-phi
###################################################
#line 1380 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
sapply(gy, coef, model = "precision")


###################################################
### chunk number 26: GasolineYield-phi
###################################################
#line 1386 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
sapply(gy, logLik)


###################################################
### chunk number 27: GasolineYield-bias2
###################################################
#line 1398 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
data("GasolineYield", package = "betareg")
gy2 <- lapply(c("ML", "BC", "BR"), function(x)
  betareg(yield ~ batch + temp | 1, data = GasolineYield, type = x))
sapply(gy2, logLik)


###################################################
### chunk number 28: ReadingSkills-bias-table
###################################################
#line 1410 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg-ext.Rnw"
cf <- matrix(paste("$", format(round(sapply(gy2, coef), digits = 5), nsmall = 5), "$\\phantom{)}", sep = ""), ncol = 3)
se <- matrix(gsub(" ", "",
  paste("(", format(round(sapply(gy2, function(x) sqrt(diag(vcov(x)))), digits = 5), nsmall = 5), ")", sep = ""),
  fixed = TRUE), ncol = 3)
cfse <- cbind(cf[,1], se[,1], cf[,2], se[,2], cf[,3], se[,3])
cfse <- cbind(
  c(paste("$\\beta_{", 1:11, "}$", sep = ""), "$\\log\\phi$"),
  cfse[, 1:5],
  paste(cfse[,6],
    c(rep("\\\\", 11), "\\\\ \\hline")))
writeLines(apply(cfse, 1, paste, collapse = " & "))


