###################################################
### chunk number 1: preliminaries
###################################################
#line 75 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
options(width = 70, prompt = "R> ", continue = "+  ")
library("betareg")


###################################################
### chunk number 2: beta-distributions
###################################################
#line 128 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
par(mfrow = c(1, 2), mar = c(4.1, 4.1, 4.1, 0.1))
dbeta2 <- function(x, mu, phi = 1) dbeta(x, mu * phi, (1 - mu) * phi)
x <- seq(from = 0.01, to = 0.99, length = 200)
xx <- cbind(x, x, x, x, x)

yy <- cbind(
  dbeta2(x, 0.10, 5),
  dbeta2(x, 0.25, 5),
  dbeta2(x, 0.50, 5),
  dbeta2(x, 0.75, 5),
  dbeta2(x, 0.90, 5)
)
matplot(xx, yy, type = "l", xlab = "y", ylab = "Density", main = expression(phi == 5),
  lty = 1, col = "black", ylim = c(0, 15))
text(0.05, 12  , "0.10")
text(0.95, 12  , "0.90")
text(0.22,  2.8, "0.25")
text(0.78,  2.8, "0.75")
text(0.50,  2.3, "0.50")

yy <- cbind(
  dbeta2(x, 0.10, 100),
  dbeta2(x, 0.25, 100),
  dbeta2(x, 0.50, 100),
  dbeta2(x, 0.75, 100),
  dbeta2(x, 0.90, 100)
)
matplot(xx, yy, type = "l", xlab = "y", ylab = "", main = expression(phi == 100),
  lty = 1, col = "black", ylim = c(0, 15))
text(0.10, 14.5, "0.10")
text(0.90, 14.5, "0.90")
text(0.25,  9.8, "0.25")
text(0.75,  9.8, "0.75")
text(0.50,  8.6, "0.50")


###################################################
### chunk number 3: GasolineYield-betareg
###################################################
#line 509 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
data("GasolineYield", package = "betareg")
gy_logit <- betareg(yield ~ batch + temp, data = GasolineYield)


###################################################
### chunk number 4: GasolineYield-loglog
###################################################
#line 514 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
gy_loglog <- betareg(yield ~ batch + temp, data = GasolineYield,
  link = "loglog")


###################################################
### chunk number 5: GasolineYield-visualization
###################################################
#line 535 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
redblue <- hcl(c(0, 260), 90, 40)
plot(yield ~ temp, data = GasolineYield, type = "n",
  ylab = "Proportion of crude oil converted to gasoline",
  xlab = "Temperature at which all gasoline has vaporized",
  main = "Prater's gasoline yield data")
points(yield ~ temp, data = GasolineYield, cex = 1.75, 
  pch = 19, col = rev(gray.colors(10))[as.numeric(batch)])
points(yield ~ temp, data = GasolineYield, cex = 1.75)
legend("topleft", as.character(1:10), title = "Batch",
  col = rev(gray.colors(10)), pch = 19, bty = "n")
legend("topleft", as.character(1:10), title = "Batch", pch = 1, bty = "n")
lines(150:500, predict(gy_logit, 
  newdata = data.frame(temp = 150:500, batch = "6")),
  col = redblue[2], lwd = 2, lty = 2)
lines(150:500, predict(gy_loglog, 
  newdata = data.frame(temp = 150:500, batch = "6")),
  col = redblue[1], lwd = 2)
legend("bottomright", c("log-log", "logit"),
  col = redblue, lty = 1:2, lwd = 2, bty = "n")


###################################################
### chunk number 6: GasolineYield-betareg1
###################################################
#line 570 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 509 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#570#"
data("GasolineYield", package = "betareg")
gy_logit <- betareg(yield ~ batch + temp, data = GasolineYield)
#line 571 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
summary(gy_logit)


###################################################
### chunk number 7: GasolineYield-plot eval=FALSE
###################################################
## #line 580 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
## set.seed(123)
## plot(gy_logit, which = 1:4, type = "pearson")
## plot(gy_logit, which = 5, type = "deviance", sub.caption = "")
## plot(gy_logit, which = 1, type = "deviance", sub.caption = "")


###################################################
### chunk number 8: GasolineYield-plot1
###################################################
#line 590 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
par(mfrow = c(3, 2))
#line 580 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#591#"
set.seed(123)
plot(gy_logit, which = 1:4, type = "pearson")
plot(gy_logit, which = 5, type = "deviance", sub.caption = "")
plot(gy_logit, which = 1, type = "deviance", sub.caption = "")
#line 592 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 9: GasolineYield-update
###################################################
#line 606 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
gy_logit4 <- update(gy_logit, subset = -4)
coef(gy_logit, model = "precision")
coef(gy_logit4, model = "precision")


###################################################
### chunk number 10: FoodExpenditure-lm
###################################################
#line 616 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
data("FoodExpenditure", package = "betareg")
fe_lm <- lm(I(food/income) ~ income + persons, data = FoodExpenditure)


###################################################
### chunk number 11: FoodExpenditure-betareg
###################################################
#line 621 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
fe_beta <- betareg(I(food/income) ~ income + persons,
  data = FoodExpenditure)


###################################################
### chunk number 12: FoodExpenditure-betareg2
###################################################
#line 626 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
fe_beta2 <- betareg(I(food/income) ~ income + persons | persons,
  data = FoodExpenditure)


###################################################
### chunk number 13: FoodExpenditure-visualization
###################################################
#line 642 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
redblueblack <- hcl(c(0, 260, 0), c(90, 90, 0), c(40, 40, 0))
plot(I(food/income) ~ income, data = FoodExpenditure,
  xlab = "Household income", ylab = "Proportion of food expenditures",
  main = "Food expenditures data", type = "n", ylim = c(0.04, 0.57))
points(I(food/income) ~ income, data = FoodExpenditure, cex = 1.75, pch = 19,
  col = rev(gray.colors(7))[persons])
points(I(food/income) ~ income, data = FoodExpenditure, cex = 1.75)
legend("bottomleft", rev(as.character(sort(unique(FoodExpenditure$persons)))),
  title = "Persons", col = gray.colors(7), pch = 19, bty = "n")
legend("bottomleft", rev(as.character(sort(unique(FoodExpenditure$persons)))),
  title = "Persons", pch = 1, bty = "n")
lines(10:100, predict(fe_lm, 
  newdata = data.frame(income = 10:100, persons = mean(FoodExpenditure$persons))),
  col = redblueblack[3], lwd = 2, lty = 2)
lines(10:100, predict(fe_beta, 
  newdata = data.frame(income = 10:100, persons = mean(FoodExpenditure$persons))),
  col = redblueblack[2], lwd = 2, lty = 5)
lines(10:100, predict(fe_beta2, 
  newdata = data.frame(income = 10:100, persons = mean(FoodExpenditure$persons))),
  col = redblueblack[1], lwd = 2)
legend("topright", c("logit, var. disp.", "logit, fix. disp.", "lm"),
  col = redblueblack, lty = c(1, 5, 2), lwd = 2, bty = "n")


###################################################
### chunk number 14: FoodExpenditure-lm1
###################################################
#line 681 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 616 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#681#"
data("FoodExpenditure", package = "betareg")
fe_lm <- lm(I(food/income) ~ income + persons, data = FoodExpenditure)
#line 682 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 15: FoodExpenditure-bptest
###################################################
#line 690 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
library("lmtest")
bptest(fe_lm)


###################################################
### chunk number 16: FoodExpenditure-betareg1
###################################################
#line 701 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 621 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#701#"
fe_beta <- betareg(I(food/income) ~ income + persons,
  data = FoodExpenditure)
#line 702 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
summary(fe_beta)


###################################################
### chunk number 17: GasolineYield-phireg
###################################################
#line 730 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
gy_logit2 <- betareg(yield ~ batch + temp | temp, data = GasolineYield)


###################################################
### chunk number 18: GasolineYield-phireg-coef
###################################################
#line 738 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
printCoefmat(summary(gy_logit2)$coefficients$precision)


###################################################
### chunk number 19: GasolineYield-lrtest
###################################################
#line 746 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
lrtest(gy_logit, gy_logit2)


###################################################
### chunk number 20: FoodExpenditure-betareg2a
###################################################
#line 764 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 626 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#764#"
fe_beta2 <- betareg(I(food/income) ~ income + persons | persons,
  data = FoodExpenditure)
#line 765 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 21: FoodExpenditure-comparison
###################################################
#line 772 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
lrtest(fe_beta, fe_beta2)
AIC(fe_beta, fe_beta2, k = log(nrow(FoodExpenditure)))


###################################################
### chunk number 22: GasolineYield-loglog1
###################################################
#line 795 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 514 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#795#"
gy_loglog <- betareg(yield ~ batch + temp, data = GasolineYield,
  link = "loglog")
#line 796 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 23: GasolineYield-Rsquared
###################################################
#line 801 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
summary(gy_logit)$pseudo.r.squared
summary(gy_loglog)$pseudo.r.squared


###################################################
### chunk number 24: GasolineYield-AIC
###################################################
#line 812 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
AIC(gy_logit, gy_logit2, gy_loglog)


###################################################
### chunk number 25: GasolineYield-reset
###################################################
#line 832 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
lrtest(gy_logit, . ~ . + I(predict(gy_logit, type = "link")^2))
lrtest(gy_loglog, . ~ . + I(predict(gy_loglog, type = "link")^2))


###################################################
### chunk number 26: GasolineYield-diagnostics
###################################################
#line 841 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
plot(abs(residuals(gy_loglog, type = "response")),
  abs(residuals(gy_logit, type = "response")))
abline(0, 1, lty = 2)


###################################################
### chunk number 27: GasolineYield-diagnostics1 eval=FALSE
###################################################
## #line 856 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
## #line 841 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#856#"
## plot(abs(residuals(gy_loglog, type = "response")),
##   abs(residuals(gy_logit, type = "response")))
## abline(0, 1, lty = 2)
## #line 857 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 28: GasolineYield-loglog
###################################################
#line 879 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
gy_loglog2 <- update(gy_loglog, link.phi = "log")
summary(gy_loglog2)$iterations


###################################################
### chunk number 29: FoodExpenditure-links
###################################################
#line 903 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
sapply(c("logit", "probit", "cloglog", "cauchit", "loglog"),
  function(x) logLik(update(fe_beta2, link = x)))


###################################################
### chunk number 30: ReadingSkills-eda
###################################################
#line 923 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
data("ReadingSkills", package = "betareg")
rs_accuracy <- format(round(with(ReadingSkills, tapply(accuracy, dyslexia, mean)), digits = 3))


###################################################
### chunk number 31: ReadingSkills-ols
###################################################
#line 928 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
data("ReadingSkills", package = "betareg")
rs_ols <- lm(qlogis(accuracy) ~ dyslexia * iq, data = ReadingSkills)


###################################################
### chunk number 32: ReadingSkills-beta
###################################################
#line 933 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
rs_beta <- betareg(accuracy ~ dyslexia * iq | dyslexia + iq,
  data = ReadingSkills, hessian = TRUE)


###################################################
### chunk number 33: ReadingSkills-visualization
###################################################
#line 953 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
cl1 <- hcl(c(260, 0), 90, 40)
cl2 <- hcl(c(260, 0), 10, 95)
plot(accuracy ~ iq, data = ReadingSkills, col = cl2[as.numeric(dyslexia)],
  main = "Reading skills data", xlab = "IQ score", ylab = "Reading accuracy",
  pch = c(19, 17)[as.numeric(dyslexia)], cex = 1.5)
points(accuracy ~ iq, data = ReadingSkills, cex = 1.5,
  pch = (1:2)[as.numeric(dyslexia)], col = cl1[as.numeric(dyslexia)])
nd <- data.frame(dyslexia = "no", iq = -30:30/10)
lines(nd$iq, predict(rs_beta, nd), col = cl1[1], lwd = 2)
lines(nd$iq, plogis(predict(rs_ols, nd)), col = cl1[1], lty = 2, lwd = 2)
nd <- data.frame(dyslexia = "yes", iq = -30:30/10)
lines(nd$iq, predict(rs_beta, nd), col = cl1[2], lwd = 2)
lines(nd$iq, plogis(predict(rs_ols, nd)), col = cl1[2], lty = 2, lwd = 2)
legend("topleft", c("control", "dyslexic", "betareg", "lm"),
  lty = c(NA, NA, 1:2), pch = c(19, 17, NA, NA), lwd = 2,
  col = c(cl2, 1, 1), bty = "n")
legend("topleft", c("control", "dyslexic", "betareg", "lm"),
  lty = c(NA, NA, 1:2), pch = c(1, 2, NA, NA),
  col = c(cl1, NA, NA), bty = "n")


###################################################
### chunk number 34: ReadingSkills-ols1
###################################################
#line 988 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 928 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#988#"
data("ReadingSkills", package = "betareg")
rs_ols <- lm(qlogis(accuracy) ~ dyslexia * iq, data = ReadingSkills)
#line 989 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
coeftest(rs_ols)


###################################################
### chunk number 35: ReadingSkills-beta1
###################################################
#line 1000 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 933 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#1000#"
rs_beta <- betareg(accuracy ~ dyslexia * iq | dyslexia + iq,
  data = ReadingSkills, hessian = TRUE)
#line 1001 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
coeftest(rs_beta)


###################################################
### chunk number 36: strucchange-data
###################################################
#line 1068 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
set.seed(123)
y1 <- c(rbeta(150, 0.3 * 4, 0.7 * 4), rbeta(50, 0.5 * 4, 0.5 * 4))
y2 <- c(rbeta(100, 0.3 * 4, 0.7 * 4), rbeta(100, 0.3 * 8, 0.7 * 8))


###################################################
### chunk number 37: strucchange-gefp
###################################################
#line 1078 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
library("strucchange")
y1_gefp <- gefp(y1 ~ 1, fit = betareg)
y2_gefp <- gefp(y2 ~ 1, fit = betareg)


###################################################
### chunk number 38: strucchange-plot1 eval=FALSE
###################################################
## #line 1086 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
## plot(y1_gefp, aggregate = FALSE)


###################################################
### chunk number 39: strucchange-plot2 eval=FALSE
###################################################
## #line 1089 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
## plot(y2_gefp, aggregate = FALSE)


###################################################
### chunk number 40: strucchange-plot eval=FALSE
###################################################
## #line 1092 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
## #line 1086 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#1092#"
## plot(y1_gefp, aggregate = FALSE)
## #line 1093 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
## #line 1089 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#1093#"
## plot(y2_gefp, aggregate = FALSE)
## #line 1094 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 41: strucchange-plot1a
###################################################
#line 1108 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 1086 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#1108#"
plot(y1_gefp, aggregate = FALSE)
#line 1109 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


###################################################
### chunk number 42: strucchange-plot2a
###################################################
#line 1111 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"
#line 1089 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw#from line#1111#"
plot(y2_gefp, aggregate = FALSE)
#line 1112 "d:/Rcompile/CRANpkg/local/2.12/betareg/inst/doc/betareg.Rnw"


